# Based on the original located here
# ftp://ftp.ncdc.noaa.gov/pub/data/paleo/climate_forcing/orbital_variations/huybers2006insolation/
# make_integrated_insolation_tables.m

#Description: 
#
# This program generates the summer energy tables accompanying this
# submission. Summer energies (in Giga-Joules/m^2) are reported at each five
# degree latitude increment from 90S to 90N in an individual table.  Rows in
# each table correspond to kila-years before present (0 to 5000ky BP) and columns to
# different threshold values (0 to 600 W/m^2 at 25 W/m^2 increments).  Note
# that computation time, depending upon the machine, can take many hours.

# orbital parameter lookup and daily insolation calculations
source("daily_insolation.R")


# http://cran.r-project.org/doc/contrib/R-and-octave.txt
meshgrid <- function(a,b) {
  list(
       x=outer(b*0,a,FUN="+"),
       y=outer(b,a*0,FUN="+")
       )
} 


#lat= seq(-90,90,30);   #latitude
lat= seq(-90,90,5);   #latitude
#tau=seq(0,600,100);   #threshold values in W/m^2.
tau=seq(0,600,25);   #threshold values in W/m^2.
#day=seq(1,365.2,by=.1); #day of the year, where day 1 is January 1st.
day=seq(1,365,by=.1); #day of the year, where day 1 is January 1st.
#day=seq(1,365.2,by=0.1); #day of the year, where day 1 is January 1st.
# [kyear_grid day_grid]=meshgrid(kyear,day);

# had to break the 5000 kyear period into 10 loops
# not enough memory for one go


for (ct_kyear in 1:5) {
  ct_lo <- ifelse(ct_kyear == 1, 0, (ct_kyear-1)*1000+1)
  ct_hi = (ct_kyear)*1000

  kyear=seq(ct_lo,ct_hi,1);   #thousands of years before present 
  g <- meshgrid(kyear,day); # see function meshgrid below
  kyear_grid=g$x; 
  day_grid=g$y; 

  # for each latitude band
  for (ct_lat in 1:length(lat)) {
    J <- matrix(NA,nrow=length(kyear), ncol=length(tau))

    # Calculate integrated summer energy
    # the 2 parameter = 360 day year starting in equinox
    Fsw=matrix(daily_insolation(kyear_grid,lat[ct_lat],day_grid,2),nrow=length(day))

    # for each forcing threshold
    for (ct_tau in 1:length(tau)) {
      Fsw_temp <- ifelse(Fsw>tau[ct_tau],Fsw,0)
      # I am integrating by 1 day, so scale is (1/1) 
      J[,ct_tau]=t(colSums(Fsw_temp)*(1/10)*(24*3600)/1e9); 
      #values are in (W/m^2) * (1 day / 10 increment) * (24*3600 seconds/day)
      #*(1 Giga-Joule / 1e9 Joules) gives output in Giga-Joules/m^2. 
      rm(Fsw_temp)
    }
    rm(Fsw)

    #add column indicating kila-year
    #J=[kyear' J'];
    J=cbind(kyear,J);
    #J=append(kyear[1],J);
    j <- sprintf("%3d  ",tau)
    colnames(J)= c("NA", j)

    #write file
    if (lat[ct_lat]<0) {
      fname = paste('data/',abs(lat[ct_lat]),'-South.txt',sep="");
    } else {
      fname = paste('data/',abs(lat[ct_lat]),'-North.txt',sep="");
    }

    options(digits=4)
    if (ct_kyear == 0) {
      sink(fname)
        print('Table of integrated summer insolation.',quote=F)
        print('The name of the file indicates the latitude.',quote=F) 
        print('Rows correspond to time and columns to diurnal average insolation thresholds.',quote=F) 
        print('Time (kilayears before present) is indicated in the first column and thresholds (W/m^2) in the first row.',quote=F)
        print('',quote=F)
        print('Peter Huybers, Harvard University, 2006.  (phuybers@fas.harvard.edu)',quote=F)
        print('Translated to R, R Broberg, 2011 (http://rhinohide.wordpress.com)',quote=F)
        print('',quote=F)
      sink()
      write.table(J, fname, row.names=F, col.names=F, quote=F,append=F)
    } else {
      write.table(J, fname, row.names=F, col.names=F, quote=F,append=T)
    }
    rm(J)
  }
  rm(kyear)
}
rm(list=ls(all=TRUE))


